clc  % Clear Command Window
clear  %Remove items from workspace, freeing up system memory
close all % Remove specified figure

ts=0.1; % sample time
t=0:ts:80; % vector time

% Parameters
D=0.5;
R=0.1;


% velocities
thethap=0.5*ones(1,length(t));
wpsi=0.1*sin(0.1*t);


% initial center position of robot
hx(1)=0;
hy(1)=0;
phi(1)=0;
psi(1)=-pi/6;


for k=1:length(t)

   
    % Kinematic Model
    hxp(k)=R*thethap(k)*cos(psi(k))*cos(phi(k));
    hyp(k)=R*thethap(k)*cos(psi(k))*sin(phi(k));
    phip(k)=(1/D)*R*thethap(k)*sin(psi(k));
    psip(k)=wpsi(k);
    
    %numerical integral (Euler Method)
    hx(k+1)=hx(k)+ts*hxp(k);
    hy(k+1)=hy(k)+ts*hyp(k);
    phi(k+1)=phi(k)+ts*phip(k);
    psi(k+1)=psi(k)+ts*psip(k);
    
    
end

scene=figure;  % new figure
tam=get(0,'ScreenSize');
set(scene,'position',[tam(1) tam(2) tam(3) tam(4)]); % position and size figure in the screen

axis equal; % Set axis aspect ratios
axis([-2 2 -2 2 0 1]); % Set axis limits 
grid on; % Display axes grid lines

hold on; % Retain current plot when adding new plot
plot(hx,hy,'r','LineWidth',2); % plot trayectory.
xlabel('x(m)'); ylabel('y(m)'); zlabel('z(m)'); % Label axis




